@@ -7,20 +7,32 @@ Command line interface for tools in Arnica
 
 
 import click
-
+import arnica
 
 # --------------------------------------
 
 
+def add_version(f):
+    """
+    Add the version of the tool to the help heading.
+    :param f: function to decorate
+    :return: decorated function
+    """
+    doc = f.__doc__
+    f.__doc__ = "Package " + arnica.__name__ + " v" + arnica.__version__ + "\n\n" + doc
+
+    return f
+
+
 @click.group()
+@add_version
 def main_cli():
     """---------------    ARNICA  --------------------
 
-You are now using the Command line interface of Arnica,
-a Python3 helper for reactive multispecies computation, created at CERFACS (https://cerfacs.fr).
+    You are now using the Command line interface of Arnica,
+    a Python3 helper for reactive multispecies computation, created at CERFACS (https://cerfacs.fr).
 
-This is a python package currently installed in your python environement.
-"""
+    This is a python package currently installed in your python environement."""
     pass
 
 
@@ -34,7 +46,7 @@ def plotcsv(filename, list_vars):
     LIST_VARS is the names of the column to plot separated by ":"
     the first will the the x_axis
     all the others will be the curves on y_axis
-    
+
     ---
 
     Example:
@@ -51,7 +63,7 @@ def plotcsv(filename, list_vars):
     >arnica plotcsv toto.csv aa:bb:cc:dd
     will plot
 
-    bb .vs. aa, cc .vs. aa, dd .vs. aa, 
+    bb .vs. aa, cc .vs. aa, dd .vs. aa,
 
 
     """
@@ -59,4 +71,5 @@ def plotcsv(filename, list_vars):
 
     print(plot_csv_data(filename, list_vars.split(":")))
 
-main_cli.add_command(plotcsv)
\ No newline at end of file
+
+main_cli.add_command(plotcsv)
