@@ -9,7 +9,7 @@ The 2nd order finit difference scheme is used to solve the inside of a computati
 This development is now hosted in a separate repository at `nitrox - calcifer <https://nitrox.cerfacs.fr/open-source/calcifer>`_
 """
 
-from .boundary import *
-from .conduction import *
-from .core_fd import *
-from .radiation import *
+from arnica.solvers_2d.boundary import *
+from arnica.solvers_2d.conduction import *
+from arnica.solvers_2d.core_fd import *
+from arnica.solvers_2d.radiation import *
