@@ -1,2 +1,2 @@
 # TODO: remove (here only for backward compatibility) -> use kokiy
-from kokiy import AxiShell
\ No newline at end of file
+from kokiy.axishell import AxiShell
\ No newline at end of file
